@@ -145,7 +145,7 @@ def in_notebook(out = None):
     return "ipykernel" in sys.modules
 
 
-def view(x, vars=None, autoscale=True, out = None):
+def view(x, vars=None, autoscale=True,out = None, **kwargs):
     """
     Plot the contents of a NetCDF out
     Parameters
@@ -433,7 +433,7 @@ def view(x, vars=None, autoscale=True, out = None):
         intplot = df.hvplot(
             groupby="variable",
             dynamic=True,
-            responsive=(in_notebook(out) is False),
+            responsive=(in_notebook() is False), **kwargs,
         )
         if in_notebook(out):
             if out is None:
@@ -497,9 +497,9 @@ def view(x, vars=None, autoscale=True, out = None):
                         quadmesh = True
 
                 if quadmesh:
-                    intplot = ds.hvplot.quadmesh(x_var, y_var, vars, cmap="viridis")
+                    intplot = ds.hvplot.quadmesh(x_var, y_var, vars, cmap="viridis", **kwargs)
                 else:
-                    intplot = ds.hvplot.image(x_var, y_var, vars, cmap="viridis")
+                    intplot = ds.hvplot.image(x_var, y_var, vars, cmap="viridis", **kwargs)
 
             else:
 
@@ -541,7 +541,7 @@ def view(x, vars=None, autoscale=True, out = None):
                             y_var,
                             vars,
                             cmap="RdBu_r",
-                            responsive=(in_notebook(out) is False),
+                            responsive=(in_notebook() is False), **kwargs,
                         ).redim.range(**{vars: (-v_max, v_max)})
                     else:
                         intplot = ds.hvplot.image(
@@ -550,14 +550,14 @@ def view(x, vars=None, autoscale=True, out = None):
                             vars,
                             cmap="RdBu_r",
                             rasterize=False,
-                            responsive=(in_notebook(out) is False),
+                            responsive=(in_notebook() is False), **kwargs,
                         ).redim.range(**{vars: (-v_max, v_max)})
 
                 else:
                     if quadmesh:
-                        intplot = ds.hvplot.quadmesh(x_var, y_var, vars, cmap="viridis")
+                        intplot = ds.hvplot.quadmesh(x_var, y_var, vars, cmap="viridis", **kwargs)
                     else:
-                        intplot = ds.hvplot.image(x_var, y_var, vars, cmap="viridis")
+                        intplot = ds.hvplot.image(x_var, y_var, vars, cmap="viridis", **kwargs)
 
             if in_notebook(out):
                 if out is None:
@@ -663,11 +663,11 @@ def view(x, vars=None, autoscale=True, out = None):
 
                     if quadmesh:
                         intplot = ds.hvplot.quadmesh(
-                            x_var, y_var, vars, cmap="viridis", rasterize=True
+                            x_var, y_var, vars, cmap="viridis", rasterize=True, **kwargs
                         )
                     else:
                         intplot = ds.hvplot.image(
-                            x_var, y_var, vars, cmap="viridis", rasterize=False
+                            x_var, y_var, vars, cmap="viridis", rasterize=False, **kwargs
                         )
 
                     if in_notebook(out):
@@ -716,7 +716,7 @@ def view(x, vars=None, autoscale=True, out = None):
             .hvplot(
                 groupby="variable",
                 dynamic=True,
-                responsive=(in_notebook(out) is False),
+                responsive=(in_notebook() is False), **kwargs,
             )
         )
         if in_notebook(out):
@@ -753,7 +753,8 @@ def view(x, vars=None, autoscale=True, out = None):
                 coastline=coastline,
                 projection=projection,
                 rasterize=rasterize,
-                responsive=in_notebook(out) is False,
+                responsive=in_notebook() is False,
+                **kwargs
             )
         else:
 
@@ -772,7 +773,8 @@ def view(x, vars=None, autoscale=True, out = None):
                 coastline=coastline,
                 rasterize=False,
                 projection=projection,
-                responsive=in_notebook(out) is False,
+                responsive=in_notebook() is False,
+                **kwargs
             )
 
         if in_notebook(out):
@@ -821,7 +823,8 @@ def view(x, vars=None, autoscale=True, out = None):
                         coastline=coastline,
                         projection=projection,
                         rasterize=rasterize,
-                        responsive=(in_notebook(out) is False),
+                        responsive=(in_notebook() is False),
+                        **kwargs
                     ).redim.range(**{vars: (-v_max, v_max)})
                 else:
                     intplot = ds.hvplot.quadmesh(
@@ -833,7 +836,8 @@ def view(x, vars=None, autoscale=True, out = None):
                         coastline=coastline,
                         projection=projection,
                         rasterize=rasterize,
-                        responsive=(in_notebook(out) is False),
+                        responsive=(in_notebook() is False),
+                        **kwargs
                     )
                 # intplot = pn.Row(pn.WidgetBox(w1), intplot)
             else:
@@ -853,7 +857,8 @@ def view(x, vars=None, autoscale=True, out = None):
                         projection=projection,
                         rasterize=False,
                         cmap="RdBu_r",
-                        responsive=(in_notebook(out) is False),
+                        responsive=(in_notebook() is False),
+                        **kwargs
                     ).redim.range(**{vars: (-v_max, v_max)})
                 else:
                     intplot = ds.hvplot.image(
@@ -865,7 +870,8 @@ def view(x, vars=None, autoscale=True, out = None):
                         projection=projection,
                         rasterize=False,
                         cmap="RdBu_r",
-                        responsive=(in_notebook(out) is False),
+                        responsive=(in_notebook() is False),
+                        **kwargs
                     )
 
             if in_notebook(out):
@@ -899,7 +905,8 @@ def view(x, vars=None, autoscale=True, out = None):
                         coastline=coastline,
                         projection=projection,
                         rasterize=rasterize,
-                        responsive=(in_notebook(out) is False),
+                        responsive=(in_notebook() is False),
+                        **kwargs
                     ).redim.range(**{vars: (self_min.values, v_max)})
                 else:
                     intplot = ds.hvplot.quadmesh(
@@ -911,7 +918,8 @@ def view(x, vars=None, autoscale=True, out = None):
                         coastline=coastline,
                         projection=projection,
                         rasterize=rasterize,
-                        responsive=(in_notebook(out) is False),
+                        responsive=(in_notebook() is False),
+                        **kwargs
                     )
 
             else:
@@ -932,7 +940,8 @@ def view(x, vars=None, autoscale=True, out = None):
                         coastline=coastline,
                         rasterize=False,
                         projection=projection,
-                        responsive=(in_notebook(out) is False),
+                        responsive=(in_notebook() is False),
+                        **kwargs
                     ).redim.range(**{vars: (self_min.values, v_max)})
                 else:
                     intplot = ds.hvplot.image(
@@ -944,7 +953,8 @@ def view(x, vars=None, autoscale=True, out = None):
                         coastline=coastline,
                         rasterize=False,
                         projection=projection,
-                        responsive=(in_notebook(out) is False),
+                        responsive=(in_notebook() is False),
+                        **kwargs
                     )
 
             if in_notebook(out):
